@@ -192,7 +192,13 @@ class ModularClient(object):
             args_list = self._args_dict_to_list(args_dict)
         else:
             args_list = args
-        result = self._send_request_by_method_name(method_name,*args_list)
+        try:
+            result = self._send_request_by_method_name(method_name,*args_list)
+        except Exception as e:
+            write_data = self._serial_interface._write_data
+            read_data = self._serial_interface._read_data
+            error_message = 'serial_interface.write_data:{0},serial_interface.read_data:{1}'.format(write_data,read_data)
+            raise e from Exception(error_message)
         return result
 
     def _create_methods(self):
